<?php

namespace CodeClouds\Unify\Actions;

use \CodeClouds\Unify\Service\Request;
use \CodeClouds\Unify\Service\Mapping\Fields;
use \CodeClouds\Unify\Service\Notice;
use \CodeClouds\Unify\Service\Helper;
/**
 * Product actions.
 * @package CodeClouds\Unify
 */
class Product
{
    /**
     * Add connection's product ID field into "Linked Products" tab.
     */
    public static function product_options_grouping()
    {
        foreach(Fields::get() as $field)
        {
            \woocommerce_wp_text_input([
                'id'          => $field['id'],
                'label'       => sanitize_text_field($field['label']),
                'desc_tip'    => true,
                'description' => sanitize_text_field($field['description']),
            ]);
        }
    }

    /**
     * Save connection's product ID.
     * @param int $post_id
     */
    public static function save_connection_id($post_id)
    {
        foreach(Fields::get() as $field)
        {
            \update_post_meta(
                    $post_id,
                    $field['id'],
                    esc_attr(Request::getPost($field['id']))
            );
        }
    }

    /**
     * Get connection's product ID.
     * @param int $post_id
     * @return String
     */
    public static function get_connetion($post_id)
    {
        $connection = [];
        foreach(Fields::get() as $field)
        {
            $connection[$field['id']] = \get_post_meta($post_id, $field['id'], false)[0];
        }
        return $connection;
    }
	
    /**
     * Add product ID column.
     * @param array $columns
     * @return array
     */
    public static function woo_product_extra_columns($columns)
    {
        $newcolumns = [
            "cb"         => "<input type  = \"checkbox\" />",
            "product_ID" => esc_html__('ID', 'woocommerce'),
        ];
        
        return array_merge($newcolumns, $columns);
    }

    /**
     * Show product ID(s) in the column.
     * @global Object $post
     * @param array $column
     */
    public static function woo_product_extra_columns_content($column)
    {
        global $post;

        $product_id = $post->ID;
        switch ($column)
        {
            case "product_ID":
                echo $product_id;
                break;
        }
    }
    
    /**
     * Import CSV and add with connection ID as per product ID.
     * Ajax action.
     */
    public static function import_connections()
    {   
		$messages = Helper::getDataFromFile('Messages');
        if(isset($_FILES['unify_import_tool']['tmp_name']) && !empty($_FILES['unify_import_tool']['tmp_name']) && strtolower(pathinfo($_FILES['unify_import_tool']['name'], PATHINFO_EXTENSION)) == 'csv')
        {
            $file = fopen($_FILES['unify_import_tool']['tmp_name'], 'r');
            fgetcsv($file);
            while (($line = fgetcsv($file)) !== FALSE)
            {
                if(!empty($line[2]))
                {
                    foreach(Fields::get() as $key=>$field)
                    {
                        update_post_meta($line[0], $field['id'], esc_attr($line[2 + $key]));
                    }
                }
            }
            fclose($file);
			
			$msg = $messages['FILES']['VALID'];
			Notice::setFlashMessage('success', $msg);
			
            echo 1;
			exit();
        }
		
		$msg = $messages['FILES']['INVALID'];
		Notice::setFlashMessage('error', $msg);
    }
    
    /**
     * Download CSV of products (ID & title)
     */
	public static function download_csv()
	{
		$crm = '';
		$setting_option = \get_option('woocommerce_codeclouds_unify_settings');

		if (!empty($setting_option) && $setting_option['enabled'] == 'yes' && !empty($setting_option['connection']))
		{
			$meta_data = \get_post_meta($setting_option['connection'], 'unify_connection_crm');

			if (!empty($meta_data))
			{
				$crm = $meta_data[0];
			}
		}

		$args = array(
			'post_type' => 'product',
			'posts_per_page' => -1,
		);
		$loop = new \WP_Query($args);

		header('Content-Type: text/csv');
		header('Content-Disposition: attachment; filename="unify.csv"');

		$fp = fopen('php://output', 'wb');
		
		if (!empty($crm) && $crm == 'limelight')
		{
			fputcsv($fp, ['Product ID', 'Title', 'Connection Product ID', 'Shipping ID (Only for LimeLight)', 'Offer ID (Only for LimeLight)', 'Billing Model ID (Only for LimeLight)']);
		}
		else
		{
			fputcsv($fp, ['Product ID', 'Title', 'Connection Product ID']);
		}

		while ($loop->have_posts()) : $loop->the_post();
			if (!empty($crm) && $crm == 'limelight')
			{
				fputcsv(
					$fp, [
					get_the_ID(),
					get_the_title(),
					get_post_meta(get_the_ID(), 'codeclouds_unify_connection', true),
					get_post_meta(get_the_ID(), 'codeclouds_unify_shipping', true),
					get_post_meta(get_the_ID(), 'codeclouds_unify_offer_id', true),
					get_post_meta(get_the_ID(), 'codeclouds_unify_billing_model_id', true)
					]
				);
			}
			else
			{
				fputcsv(
					$fp, [
					get_the_ID(),
					get_the_title(),
					get_post_meta(get_the_ID(), 'codeclouds_unify_connection', true)
					]
				);
			}
		endwhile;
		wp_reset_query();

		fclose($fp);
	}

	public static function product_mapping()
    {
        foreach (Request::post('map') as $id => $item)
		{
			foreach ($item as $key => $value)
			{
				if (!empty($value))
				{
					update_post_meta($id, 'codeclouds_unify_' . $key, $value);
				}
				else
				{
					$meta = get_post_meta($id, 'codeclouds_unify_' . $key, true);

					if (!empty($meta))
					{
						delete_post_meta($id, 'codeclouds_unify_' . $key, $value);
					}
				}
			}
		}

		wp_redirect(Request::post('_wp_http_referer'));
		die();
    }
}
