<?php

namespace CodeClouds\Unify\Data_Sources\Handler;

/**
 * Handle Limelight API for process orders.
 * @package CodeClouds\Unify
 */
class Limelight_Handler extends \CodeClouds\Unify\Abstracts\Order_Abstract
{
	private $debug = false;
    /**
     * Connection authentication.
     * @param array $args Information for API.
     */
    public function __construct($args)
    {
        $this->api_payload  = $args;
        $this->api_instance = new \CodeClouds\Limelight\API(
                $this->api_payload['config']['endpoint'],
                $this->api_payload['config']['api_username'],
                \stripslashes($this->api_payload['config']['api_password'])
        );
    }

	public function set_config($connection, $name)
    {
        if(!empty($this->api_payload['config']['offer_model']) && $this->api_payload['config']['offer_model'] == 1)
        {
            $this->api_config = \file_get_contents(__DIR__ . '/../../Config/' . strtolower($connection) . '/om_' . $name . '.config.json');
        }
        else
        {
            parent::set_config($connection, $name);
        }
    }

    /**
     * Call API for payment process.
     * @return array
     */
    public function make_order()
    {
		$return = [];
		$this->prepare_order_payload();

		$wc_codeclouds_unify_settings = get_option('woocommerce_codeclouds_unify_settings');
		$context = array( 'source' => 'Unify-App' );
		if(!empty($wc_codeclouds_unify_settings['enable_debugging']) && $wc_codeclouds_unify_settings['enable_debugging'] == 'yes'){
			$this->debug = true;
		}
		
		if (!empty($this->api_payload['config']['offer_model']) && $this->api_payload['config']['offer_model'] == 1)
		{
			$this->format_data();
            $this->offer_model_product_variants();
			
			if($this->debug){
				$logger = wc_get_logger();
				$temp_config = $this->api_config;
				$rep_num = substr($temp_config['creditCardNumber'], 6, -4);
				$to_rep_num = '';
				for($i = strlen($rep_num); $i > 0; $i--){
					$to_rep_num .= '*';
				}
				$temp_config['creditCardNumber'] = substr_replace($temp_config['creditCardNumber'], $to_rep_num, 6, -4);
				
				$to_rep_cvv = '';
				for($i = strlen($temp_config['CVV']); $i > 0; $i--){
					$to_rep_cvv .= '*';
				}
				$temp_config['CVV'] = str_replace($temp_config['CVV'], $to_rep_cvv, $temp_config['CVV']);
				
				$logger->info(('Blling Model Request: ' . json_encode($temp_config, JSON_PRETTY_PRINT)), $context);
			}

			$this->api_response['response'] = json_decode($this->offer_model_payment(), true);
			
			if($this->debug){
				$logger->info(('Blling Model LL Response: ' . json_encode($this->api_response, JSON_PRETTY_PRINT)), $context);
			}

			$return[] = [
				'status' => $this->api_response['response']['response_code'],
				'order_id' => $this->api_response['response']['order_id'],
				'custom_note' => empty($this->api_response['response']['declineReason']) ? $this->api_response['response']['errorMessage'] : $this->api_response['response']['declineReason']
			];
        }
		elseif (!empty($wc_codeclouds_unify_settings['shipment_price_settings']) && $wc_codeclouds_unify_settings['shipment_price_settings'] == 2)
		{
			$newCart = [];
			$cartValue = $this->api_payload['cart_items'];
			unset($this->api_payload['cart_items']);
			
			foreach ($cartValue as $k => $val)
			{
				$newCart[empty($val['connetion_shipping_id']) ? 'default' : $val['connetion_shipping_id']][] = $val;
			}
			
			foreach ($newCart as $k => $val)
			{
				unset($this->api_config['upsellProductIds']);
				unset($this->api_config['upsellCount']);
				$this->api_payload['cart_items'] = $val;
				$this->format_data();
				$this->product_variants();
				$this->api_config['shippingId'] = ($k == 'default') ? $this->api_config['shippingId'] : $k;
				$return[] = $this->call_to_proccess_order();
			}
		}
		else
		{
			$this->format_data();
			$this->product_variants();
			$this->set_shipping_product();
			$return[] = $this->call_to_proccess_order();
		}

		$order_id = '';
		$transaction_id = '';
		$custom_note = [];
		foreach ($return as $k => $val)
		{
			$order_id .= empty($order_id) ? '' : ', ';
			$transaction_id .= empty($transaction_id) ? '' : ', ';

			if ($val['status'] == 100)
			{
				$order_id .= $val['order_id'];
				$transaction_id .= $val['transaction_id'];
			}
			else
			{
				$custom_note[] = [
					'order_id' => $val['order_id'],
					'message' => empty($val['custom_note']) ? 'Something went wrong!' : $val['custom_note']
				];
			}
		}

		return ['order_id' => $order_id, 'transaction_id' => $transaction_id, 'custom_note' => $custom_note];
    }

    /**
     * Prepare order payload before sending to the API.
     */
    private function prepare_order_payload()
    {
        $this->api_payload['method']           = 'NewOrder';
        $this->api_payload['tran_type']        = 'Sale';
        $this->api_payload['upsell_count']     = true;
        $this->api_payload['card']['type']     = $this->get_cctype($this->api_payload['card']['type']);
        $this->api_payload['card']['exp_year'] = \substr($this->api_payload['card']['exp_year'], -2);
    }

    /**
     * Adding Shipping Product into order payload before sending to the API.
     */
    private function set_shipping_product()
	{
		$wc_codeclouds_unify_settings = get_option('woocommerce_codeclouds_unify_settings');
		$ship_product_id = !empty($wc_codeclouds_unify_settings['shipping_product_id']) ? $wc_codeclouds_unify_settings['shipping_product_id'] : NULL;
		if (!empty($wc_codeclouds_unify_settings['shipment_price_settings']) && ($wc_codeclouds_unify_settings['shipment_price_settings'] == 1) && !empty($ship_product_id))
		{
			$this->api_config['upsellProductIds'] = trim($this->api_config['upsellProductIds'] . ',' . $ship_product_id, ',');
			$this->api_config['upsellCount'] = 1;
			$this->api_config['dynamic_product_price_' . $ship_product_id] = !empty(WC()->cart->get_shipping_total()) ? WC()->cart->get_shipping_total() + WC()->cart->get_shipping_tax() : '0.00';
			$this->api_config['product_qty_' . $ship_product_id] = 1;
		}
	}

	/**
     * Get the name of card type.
     * @param type $cc_code
     * @return String Card type name.
     */
    private function get_cctype($cc_code)
    {
        $card_types = \json_decode(
            \file_get_contents(__DIR__ . '/../../Config/limelight/cards.json'), true
        );

        if (isset($card_types[$cc_code]))
        {
            return $card_types[$cc_code];
        }

        return '';
    }
	
	private function call_to_proccess_order()
	{
		if (count($this->api_payload['cart_items']) < 2)
		{
			$wc_codeclouds_unify_settings = get_option('woocommerce_codeclouds_unify_settings');
			$ship_product_id = !empty($wc_codeclouds_unify_settings['shipping_product_id']) ? $wc_codeclouds_unify_settings['shipping_product_id'] : NULL;
			if (empty($ship_product_id) || empty($wc_codeclouds_unify_settings['shipment_price_settings']) || $wc_codeclouds_unify_settings['shipment_price_settings'] == 2)
			{
				unset($this->api_config['upsellProductIds']);
				unset($this->api_config['upsellCount']);
			}
		}
		$context = array( 'source' => 'Unify-App' );
		if ($this->debug)
		{
			$logger = wc_get_logger();
			$temp_config = $this->api_config;
			$rep_num = substr($temp_config['creditCardNumber'], 6, -4);
			$to_rep_num = '';
			for ($i = strlen($rep_num); $i > 0; $i--)
			{
				$to_rep_num .= '*';
			}
			$temp_config['creditCardNumber'] = substr_replace($temp_config['creditCardNumber'], $to_rep_num, 6, -4);

			$to_rep_cvv = '';
			for ($i = strlen($temp_config['CVV']); $i > 0; $i--)
			{
				$to_rep_cvv .= '*';
			}
			$temp_config['CVV'] = str_replace($temp_config['CVV'], $to_rep_cvv, $temp_config['CVV']);

			$logger->info(('LL Request: ' . json_encode($temp_config, JSON_PRETTY_PRINT)), $context);
		}
		
		$this->api_response = $this->api_instance->newOrder($this->api_config)->getInArray();
		
		if ($this->debug)
		{
			$logger->info(('LL Response: ' . json_encode($this->api_response, JSON_PRETTY_PRINT)), $context);
		}

		if ($this->api_response['response']['responseCode'] == 100)
		{
			return [
				'status' => $this->api_response['response']['responseCode'],
				'order_id' => $this->api_response['response']['orderId'],
				'transaction_id' => $this->api_response['response']['transactionID']
			];
		}
		else
		{
			return [
				'status' => $this->api_response['response']['responseCode'],
				'order_id' => $this->api_response['response']['orderId'],
				'custom_note' => empty($this->api_response['response']['declineReason']) ? $this->api_response['response']['errorMessage'] : $this->api_response['response']['declineReason']
			];
		}

		return ['status' => $this->api_response['response']['responseCode']];
	}

	/**
	 * Add product variants if exist
	 */
	private function product_variants()
	{
		$variants = [];

		foreach ($this->api_payload['cart_items'] as $product)
		{
			if (!empty($product['variants']))
			{
				foreach ($product['variants'] as $variant)
				{
					$variants[$product['connetion_product_id']][$variant['key']] = $variant['value'];
				}
			}
		}

		$this->api_config['product_attribute'] = $variants;
	}

	/**
	 * Add product variants if exist for offer model
	 */
	private function offer_model_product_variants()
	{
		foreach ($this->api_payload['cart_items'] as $key => $product)
		{
			if ($product['variants'])
			{
				foreach ($product['variants'] as $variant)
				{
					$this->api_config['offers'][$key]['variant'][] = [
						'attribute_name' => $variant['key'],
						'attribute_value' => $variant['value']
					];
				}
			}
		}
	}

	private function offer_model_payment()
	{
		$curl = curl_init();

		curl_setopt_array($curl, array(
			CURLOPT_URL => rtrim($this->api_payload['config']['endpoint']) . '/api/v1/new_order',
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING => "",
			CURLOPT_MAXREDIRS => 10,
			CURLOPT_TIMEOUT => 30,
			CURLOPT_SSL_VERIFYHOST => false,
			CURLOPT_SSL_VERIFYPEER => false,
			CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			CURLOPT_POSTFIELDS => json_encode($this->api_config),
			CURLOPT_POST => true,
			CURLOPT_HTTPHEADER => array(
				"authorization: Basic " . base64_encode($this->api_payload['config']['api_username'] . ":" . $this->api_payload['config']['api_password']),
				"content-type: application/json",
			),
		));

		$response = curl_exec($curl);
		curl_close($curl);

		return $response;
	}

}
