<?php

return [
    'apiRules' => [
        'orderCalculateRefund' => [
            'order_id' => 'required|numeric',
        ],
        'orderFindOverdue'     => [
            'days' => 'required|numeric',
        ],
        'orderRefund'          => [
            'order_id'       => 'required|numeric',
            'amount'         => 'required|numeric',
            'keep_recurring' => 'boolean',
        ],
        'offerView'            => [
            'campaign_id' => 'required_without:offer_id|numeric',
            'offer_id'    => 'required_without:campaign_id|numeric',
        ],
        'orderVoid'            => [
            'order_id' => 'required|numeric',
        ],
        'orderForceBill'       => [
            'order_id'               => 'required|numeric',
            'forceGatewayId'         => 'numeric',
            'preserve_force_gateway' => 'numeric',
        ],
        'orderUpdateRecurring' => [
            'order_id' => 'required|numeric',
            'status'   => 'required|in:start,stop,reset',
        ],
        'orderFind'            => [
            'campaign_id' => 'required',
            'product_ids' => '',
            'start_date'  => 'required|date|date_format:m/d/Y',
            'end_date'    => 'required|date|date_format:m/d/Y',
            'start_time'  => array('regex:/^([01]?[0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9]|60)$/'),
            'end_time'    => array('regex:/^([01]?[0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9]|60)$/'),
            'search_type' => 'in:any,all',
            'return_type' => 'in:,order_view',
            'criteria'    => 'string',
        ],
        'orderFindUpdated'     => [
            'campaign_id' => 'required',
            'start_date'  => 'required|date|date_format:m/d/Y',
            'end_date'    => 'required|date|date_format:m/d/Y',
            'start_time'  => array('regex:/^([01]?[0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9]|60)$/'),
            'end_time'    => array('regex:/^([01]?[0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9]|60)$/'),
            'group_keys'  => 'string',
        ],
        'orderUpdate'          => [
            'order_ids' => 'required|string',
            'sync_all'  => 'numeric',
            'actions'   => 'required|in:check_account,check_routing,cc_number,cc_expiration_date,cc_payment_type,rebill_discount,next_rebill_product,confirmation_status,blacklist,fraud,notes,chargeback,first_name,last_name,email,phone,shipping_method,shipping_address1,shipping_address2,shipping_city,shipping_zip,shipping_state,shipping_country,billing_address1,billing_address2,billing_city,billing_zip,billing_state,billing_country,recurring_date,stop_recurring_next_success,rma,return,tracking_number,payment_received,subscription_override',
            'values'    => 'string',
        ],
        'orderView'            => [
            'order_id'      => 'required',
            'return_format' => 'string',
        ],
        'orderReprocess'       => [
            'order_id' => 'required|numeric',
        ],
        'newOrder'             => [
            'firstName'                => 'required|max:64',
            'lastName'                 => 'required|max:64',
            'shippingAddress1'         => 'required|max:64',
            'shippingAddress2'         => '',
            'shippingCity'             => 'required|max:32',
            'shippingState'            => 'required|max:30',
            'shippingZip'              => 'required',
            'shippingCountry'          => 'required',
            'billingFirstName'         => '',
            'billingLastName'          => '',
            'billingAddress1'          => 'required_if:billingSameAsShipping,No|max:64',
            'billingAddress2'          => '',
            'billingCity'              => 'required_if:billingSameAsShipping,No|max:32',
            'billingState'             => 'required_if:billingSameAsShipping,No|max:32',
            'billingZip'               => 'required_if:billingSameAsShipping,No',
            'billingCountry'           => 'required_if:billingSameAsShipping,No',
            'phone'                    => 'required',
            'email'                    => 'required|email|max:96',
            'creditCardType'           => 'required|in:amex,visa,master,discover,checking,offline,solo,maestro,switch,boleto,paypal,diners,hipercard,aura,eft_germany,giro,amazon,icepay,bitcoin_pg,eurodebit,sepa,boleto_bradesco,boleto_caixa_eco_fed,boleto_hsbc,boleto_banco_do_bras,boleto_itau,cielo_visa,cielo_mastercard,cielo_amex,cielo_diners,cielo_elo,redecard_webs_visa,redecard_webs_master',
            'creditCardNumber'         => 'required',
            'expirationDate'           => 'required',
            'CVV'                      => 'numeric|required',
            'checkAccountNumber'       => 'max:50|required_if:creditCardType,checking|required_if:creditCardType,eft_germany',
            'checkRoutingNumber'       => 'max:50|required_if:creditCardType,checking|required_if:creditCardType,eft_germany',
            'sepa_iban'                => 'max:50|required_if:creditCardType,checking|required_if:creditCardType,sepa',
            'sepa_bic'                 => 'max:50|required_if:creditCardType,checking|required_if:creditCardType,sepa',
            'eurodebit_acct_num'       => 'max:50|required_if:creditCardType,checking|required_if:creditCardType,eurodebit',
            'eurodebit_route_num'      => 'max:50|required_if:creditCardType,checking|required_if:creditCardType,eurodebit',
            'tranType'                 => 'required',
            'ipAddress'                => 'max:46|required',
            'AFID'                     => 'max:255',
            'SID'                      => 'max:255',
            'AFFID'                    => 'max:255',
            'C1'                       => 'max:255',
            'C2'                       => 'max:255',
            'C3'                       => 'max:255',
            'AID'                      => 'max:255',
            'OPT'                      => 'max:255',
            'productId'                => 'integer|required',
            'campaignId'               => 'integer|required',
            'shippingId'               => 'integer|required',
            'billingSameAsShipping'    => '',
            'forceGatewayId'           => 'integer',
            'product_qty_x'            => '',
            'preserve_force_gateway'   => 'integer',
            'createdBy'                => 'max:100',
            'thm_session _id'          => 'max:255',
            'total_installments'       => 'integer',
            'alt_pay_token'            => 'max:20|required_if:creditCardType,Paypal|required_if:creditCardType,Amazon|required_if:creditCardType,IcePay',
            'alt_pay_payer_id'         => 'max:20|required_if:creditCardType,Paypal|required_if:creditCardType,Amazon|required_if:creditCardType,IcePay',
            'secretSSN'                => 'max:4',
            'force_subscription_cycle' => '',
            'recurring_days'           => 'integer',
            'subscription_week'        => 'integer',
            'subscription_day'         => '',
            'product_attribute'        => '',
            'notes'                    => '',
            'master_order_id'          => 'integer',
            'promoCode'                => 'max:100',
            'temp_customer_id'         => 'max:32',
            'three_d_redirect_url'     => '',
            'sessionId'                => 'max:30',
            'cascade_override'         => 'integer',
        ],

        'newOrderCardOnFile'   => [
            'AFID'                     => 'max:255',
            'SID'                      => 'max:255',
            'AFFID'                    => 'max:255',
            'C1'                       => 'max:255',
            'C2'                       => 'max:255',
            'C3'                       => 'max:255',
            'AID'                      => 'max:255',
            'OPT'                      => 'max:255',
            'productId'                => 'integer|required',
            'campaignId'               => 'integer|required',
            'shippingId'               => 'integer|required',
            'upsellCount'              => 'integer|required',
            'upsellProductIds'         => 'required_if:upsellCount,1',
            'previousOrderId'          => 'integer|required',
            'forceGatewayId'           => 'integer',
            'preserve_force_gateway'   => 'integer',
            'createdBy'                => 'max:100',
            'force_subscription_cycle' => '',
            'recurring_days'           => 'integer',
            'subscription_week'        => 'integer',
            'notes'                    => '',
            'subscription_day'         => '',
            'product_attribute'        => '',
            'master_order_id'          => 'integer',
            'promoCode'                => 'max:100',
            'temp_customer_id'         => 'max:32',
            'sessionId'                => 'max:30',
            'cascade_override'         => 'integer',
        ],
        'newOrderWithProspect' => [
            'firstName'                => 'required|max:64',
            'lastName'                 => 'required|max:64',
            'shippingAddress1'         => 'required|max:64',
            'shippingAddress2'         => '',
            'shippingCity'             => 'required|max:32',
            'shippingState'            => 'required|max:30',
            'shippingZip'              => 'required',
            'shippingCountry'          => 'required',
            'billingFirstName'         => '',
            'billingLastName'          => '',
            'billingAddress1'          => 'required_unless:billingSameAsShipping,Yes|max:64',
            'billingAddress2'          => '',
            'billingCity'              => 'required_unless:billingSameAsShipping,Yes|max:32',
            'billingState'             => 'required_unless:billingSameAsShipping,Yes|max:32',
            'billingZip'               => 'required_unless:billingSameAsShipping,Yes',
            'billingCountry'           => 'required_unless:billingSameAsShipping,Yes',
            'phone'                    => 'required',
            'email'                    => 'required|email|max:96',
            'creditCardType'           => 'required|in:amex,visa,master,discover,checking,offline,solo,maestro,switch,boleto,paypal,diners,hipercard,aura,eft_germany,giro,amazon,icepay,bitcoin_pg,eurodebit,sepa,boleto_bradesco,boleto_caixa_eco_fed,boleto_hsbc,boleto_banco_do_bras,boleto_itau,cielo_visa,cielo_mastercard,cielo_amex,cielo_diners,cielo_elo,redecard_webs_visa,redecard_webs_master',
            'creditCardNumber'         => 'required|numeric',
            'expirationDate'           => 'required|numeric',
            'CVV'                      => 'numeric',
            'checkAccountNumber'       => 'max:50|required_if:creditCardType,checking|required_if:creditCardType,eft_germany',
            'checkRoutingNumber'       => 'max:50|required_if:creditCardType,checking|required_if:creditCardType,eft_germany',
            'sepa_iban'                => 'max:50|required_if:creditCardType,checking|required_if:creditCardType,sepa',
            'sepa_bic'                 => 'max:50|required_if:creditCardType,checking|required_if:creditCardType,sepa',
            'eurodebit_acct_num'       => 'max:50|required_if:creditCardType,checking|required_if:creditCardType,eurodebit',
            'eurodebit_route_num'      => 'max:50|required_if:creditCardType,checking|required_if:creditCardType,eurodebit',
            'tranType'                 => 'required',
            'ipAddress'                => 'max:15|required',
            'AFID'                     => 'max:255',
            'SID'                      => 'max:255',
            'AFFID'                    => 'max:255',
            'C1'                       => 'max:255',
            'C2'                       => 'max:255',
            'C3'                       => 'max:255',
            'AID'                      => 'max:255',
            'OPT'                      => 'max:255',
            'productId'                => 'integer|required',
            'campaignId'               => 'integer|required',
            'shippingId'               => 'integer|required',
            'upsellCount'              => 'integer|required',
            'upsellProductIds'         => 'required_if:upsellCount,1',
            'billingSameAsShipping'    => '',
            'prospectId'               => 'integer|required',
            'forceGatewayId'           => 'integer',
            'product_qty_x'            => '',
            'preserve_force_gateway'   => 'integer',
            'createdBy'                => 'max:100',
            'thm_session _id'          => 'max:255',
            'total_installments'       => 'integer',
            'notes'                    => '',
            'alt_pay_token'            => 'max:20|required_if:creditCardType,Paypal|required_if:creditCardType,Amazon|required_if:creditCardType,IcePay',
            'alt_pay_payer_id'         => 'max:20|required_if:creditCardType,Paypal|required_if:creditCardType,Amazon|required_if:creditCardType,IcePay',
            'force_subscription_cycle' => '',
            'recurring_days'           => 'integer',
            'subscription_week'        => 'integer',
            'subscription_day'         => '',
            'product_attribute'        => '',
            'master_order_id'          => 'integer',
            'promoCode'                => 'max:100',
            'temp_customer_id'         => 'max:32',
            'three_d_redirect_url'     => '',
            'sessionId'                => 'max:30',
        ],

    ],
];
